
@echo OFF
cls
COLOR 0A

rem <PROGRAM-HEADER>
echo **************************************************
echo *                                                *
echo * Public IP 4                                    *
echo *                                                *
echo **************************************************
echo.
echo Description:
echo        Get public IP address.
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolm Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2015/10/07
rem         Last modification : 2015/10/07
rem         Script version    : 1.0
rem 
rem: History :
rem         1.0 (2015-10-07) : First version
rem 
rem: Bug report :
rem         None.
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolm Informatique Command Line Tools 4.x
rem 
rem: Windows compatibility :
rem         Workstations : XP SP3, Vista SP2, 7 SP1, 8, 10
rem         Server       : 2003 SP3, 2008 SP2, 2008 R2 SP2, 2012, 2012 R2
rem 
rem: Sources :
rem         None.
rem 
rem: Variables :
rem         Name                            Type       Visibility     Values / Comment
rem         ----------------------------------------------------------------------------------------------------------------
rem         g_strBatchPath                  String     Static         Current script directory.
rem         g_strCurrentDirectory           String     Static         Current directory when running this script.
rem         g_strCmdLineToolsFolder         String     Static         CmdLineTools binary folder. Change this variable to use other version of CmdLineTools.
rem         g_strInternalOutputFullFilename String     Static         Output filename for data exchange between application and script.
rem         g_strCommand%%NAME%%FullPath    String     Static         Full filename of CmdLineTools application. Replace %%NAME%% by AppVersion4, Is64Bits4...
rem 
rem         g_strAppResult                  String     Temp           Application temporary buffer.
rem 
rem: Notes :
rem         None.
rem 
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
echo [Initialisation]
echo ----------------
echo.
setlocal enabledelayedexpansion
set g_strBatchPath=%~dp0
set g_strCurrentDirectory=%CD%
set g_strCmdLineToolsFolder=!g_strBatchPath!\..\bin
set g_strInternalOutputFullFilename=%TEMP%\Nolme_SDK_Output.log

set g_strCommandPublicIP4FullPath=!g_strCmdLineToolsFolder!\PublicIP4.exe

echo Initialization done.
echo.
rem </INIT>

rem <MAIN>
echo [Main]
echo ------
echo.


REM ************************
REM * Ping Google DNS to check Internet connection
REM ************************
echo Check Internet connection
ping 8.8.8.8 -n 3 >nul
if %ERRORLEVEL%==1 (
    echo Internet connexion : [ERROR]
)
if %ERRORLEVEL%==0 (
    echo Internet connexion : [ok]
)
echo.

echo Version 1:
echo ----------
echo Get public IP:port (please wait...)
"!g_strCommandPublicIP4FullPath!" -v4
echo.

echo Get public IP:port (v2)
"!g_strCommandPublicIP4FullPath!" -v4 > "!g_strInternalOutputFullFilename!"
set /p g_strAppResult= < "!g_strInternalOutputFullFilename!"
echo Variable value : %g_strAppResult%
echo.


echo Version 2:
echo ----------
echo Get public IP (please wait...)
"!g_strCommandPublicIP4FullPath!" -v4s
echo.

echo Get public IP (v2)
"!g_strCommandPublicIP4FullPath!" -v4s > "!g_strInternalOutputFullFilename!"
set /p g_strAppResult= < "!g_strInternalOutputFullFilename!"
echo Variable value : %g_strAppResult%
echo.


echo Version 3:
echo ----------
echo Get public IP host (please wait...)
"!g_strCommandPublicIP4FullPath!" -v4h
echo.

echo Get public IP host (v2)
"!g_strCommandPublicIP4FullPath!" -v4h > "!g_strInternalOutputFullFilename!"
set /p g_strAppResult= < "!g_strInternalOutputFullFilename!"
echo Variable value : %g_strAppResult%
echo.
rem </MAIN>

rem <FOOTER>
echo.
echo [End of script]
echo ---------------
Pause
GOTO:EOF
rem </FOOTER>
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem --------------------------------------------         END OF FILE          ----------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------
rem ------------------------------------------------------------------------------------------------------------------------------------